import { defineProperty as _defineProperty, objectSpread2 as _objectSpread2 } from '../../../../../_virtual/_rollupPluginBabelHelpers.js';
import { IsFocusVisibleClassName } from '@uifabric-vue/utilities';
import { getScreenSelector, ScreenWidthMaxSmall, ScreenWidthMinMedium, ScreenWidthMaxMedium, getGlobalClassNames, FontWeights, HighContrastSelector, getFocusStyle } from '@uifabric/styling';

var GlobalClassNames = {
  root: 'ms-Breadcrumb',
  list: 'ms-Breadcrumb-list',
  listItem: 'ms-Breadcrumb-listItem',
  chevron: 'ms-Breadcrumb-chevron',
  overflow: 'ms-Breadcrumb-overflow',
  overflowButton: 'ms-Breadcrumb-overflowButton',
  itemLink: 'ms-Breadcrumb-itemLink',
  item: 'ms-Breadcrumb-item'
};
var SingleLineTextStyle = {
  whiteSpace: 'nowrap',
  textOverflow: 'ellipsis',
  overflow: 'hidden'
};
var overflowButtonFontSize = 16;
var chevronSmallFontSize = 8;
var itemLineHeight = 36;
var itemFontSize = 18;
var MinimumScreenSelector = getScreenSelector(0, ScreenWidthMaxSmall);
var MediumScreenSelector = getScreenSelector(ScreenWidthMinMedium, ScreenWidthMaxMedium);
var getStyles = function getStyles(props) {
  var _selectors2, _objectSpread2$1;

  var className = props.className,
      theme = props.theme;
  var palette = theme.palette,
      semanticColors = theme.semanticColors,
      fonts = theme.fonts;
  var classNames = getGlobalClassNames(GlobalClassNames, theme); // Tokens

  var itemBackgroundHoveredColor = semanticColors.menuItemBackgroundHovered;
  var itemBackgroundPressedColor = semanticColors.menuItemBackgroundPressed;
  var itemTextColor = palette.neutralSecondary;
  var itemTextFontWeight = FontWeights.regular;
  var itemTextHoveredOrPressedColor = palette.neutralPrimary;
  var itemLastChildTextColor = palette.neutralPrimary;
  var itemLastChildTextFontWeight = FontWeights.semibold;
  var chevronButtonColor = palette.neutralSecondary;
  var overflowButtonColor = palette.neutralSecondary;
  var lastChildItemStyles = {
    fontWeight: itemLastChildTextFontWeight,
    color: itemLastChildTextColor
  };
  var itemStateSelectors = {
    ':hover': {
      color: itemTextHoveredOrPressedColor,
      backgroundColor: itemBackgroundHoveredColor,
      cursor: 'pointer',
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Highlight'
      })
    },
    ':active': {
      backgroundColor: itemBackgroundPressedColor,
      color: itemTextHoveredOrPressedColor
    },
    '&:active:hover': {
      color: itemTextHoveredOrPressedColor,
      backgroundColor: itemBackgroundPressedColor
    },
    '&:active, &:hover, &:active:hover': {
      textDecoration: 'none'
    }
  };
  var commonItemStyles = {
    color: itemTextColor,
    padding: '0 8px',
    lineHeight: itemLineHeight,
    fontSize: itemFontSize,
    fontWeight: itemTextFontWeight
  };
  return {
    root: [classNames.root, fonts.medium, {
      margin: '11px 0 1px'
    }, className],
    list: [classNames.list, {
      whiteSpace: 'nowrap',
      padding: 0,
      margin: 0,
      display: 'flex',
      alignItems: 'stretch'
    }],
    listItem: [classNames.listItem, {
      listStyleType: 'none',
      margin: '0',
      padding: '0',
      display: 'flex',
      position: 'relative',
      alignItems: 'center',
      selectors: {
        '&:last-child .ms-Breadcrumb-itemLink': lastChildItemStyles,
        '&:last-child .ms-Breadcrumb-item': lastChildItemStyles
      }
    }],
    chevron: [classNames.chevron, {
      color: chevronButtonColor,
      fontSize: fonts.small.fontSize,
      selectors: (_selectors2 = {}, _defineProperty(_selectors2, HighContrastSelector, {
        color: 'WindowText',
        MsHighContrastAdjust: 'none'
      }), _defineProperty(_selectors2, MediumScreenSelector, {
        fontSize: chevronSmallFontSize
      }), _defineProperty(_selectors2, MinimumScreenSelector, {
        fontSize: chevronSmallFontSize
      }), _selectors2)
    }],
    overflow: [classNames.overflow, {
      position: 'relative',
      display: 'flex',
      alignItems: 'center'
    }],
    overflowButton: [classNames.overflowButton, getFocusStyle(theme), SingleLineTextStyle, {
      fontSize: overflowButtonFontSize,
      color: overflowButtonColor,
      height: '100%',
      cursor: 'pointer',
      selectors: _objectSpread2(_objectSpread2({}, itemStateSelectors), {}, (_objectSpread2$1 = {}, _defineProperty(_objectSpread2$1, MinimumScreenSelector, {
        padding: '4px 6px'
      }), _defineProperty(_objectSpread2$1, MediumScreenSelector, {
        fontSize: fonts.mediumPlus.fontSize
      }), _objectSpread2$1))
    }],
    itemLink: [classNames.itemLink, getFocusStyle(theme), SingleLineTextStyle, _objectSpread2(_objectSpread2({}, commonItemStyles), {}, {
      selectors: _objectSpread2(_defineProperty({
        ':focus': {
          color: palette.neutralDark
        }
      }, ".".concat(IsFocusVisibleClassName, " &:focus"), {
        outline: "none"
      }), itemStateSelectors)
    })],
    item: [classNames.item, _objectSpread2(_objectSpread2({}, commonItemStyles), {}, {
      selectors: {
        ':hover': {
          cursor: 'default'
        }
      }
    })]
  };
};

export { getStyles };
