import { defineProperty as _defineProperty, objectSpread2 as _objectSpread2 } from '../../../../../_virtual/_rollupPluginBabelHelpers.js';
import { IsFocusVisibleClassName } from '@uifabric-vue/utilities';
import { HighContrastSelector } from '@uifabric/styling';

var splitButtonDividerBaseStyles = function splitButtonDividerBaseStyles() {
  return {
    position: 'absolute',
    width: 1,
    right: 31,
    top: 8,
    bottom: 8
  };
};

function standardStyles(theme) {
  var s = theme.semanticColors,
      p = theme.palette;
  var buttonBackground = s.buttonBackground;
  var buttonBackgroundPressed = s.buttonBackgroundPressed;
  var buttonBackgroundHovered = s.buttonBackgroundHovered;
  var buttonText = s.buttonText;
  var buttonTextHovered = s.buttonTextHovered;
  var buttonTextChecked = s.buttonTextChecked;
  var buttonTextCheckedHovered = s.buttonTextCheckedHovered;
  return {
    root: {
      backgroundColor: buttonBackground,
      color: buttonText
    },
    rootHovered: {
      backgroundColor: buttonBackgroundHovered,
      color: buttonTextHovered,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderColor: 'Highlight',
        color: 'Highlight'
      })
    },
    rootPressed: {
      backgroundColor: buttonBackgroundPressed,
      color: buttonTextChecked
    },
    rootExpanded: {
      backgroundColor: buttonBackgroundPressed,
      color: buttonTextChecked
    },
    rootChecked: {
      backgroundColor: buttonBackgroundPressed,
      color: buttonTextChecked
    },
    rootCheckedHovered: {
      backgroundColor: buttonBackgroundPressed,
      color: buttonTextCheckedHovered
    },
    rootDisabled: {
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText',
        borderColor: 'GrayText',
        backgroundColor: 'Window'
      })
    },
    // Split button styles
    splitButtonContainer: {
      selectors: _defineProperty({}, HighContrastSelector, {
        border: 'none'
      })
    },
    splitButtonMenuButton: {
      color: p.white,
      backgroundColor: 'transparent',
      selectors: {
        ':hover': {
          backgroundColor: p.neutralLight,
          selectors: _defineProperty({}, HighContrastSelector, {
            color: 'Highlight'
          })
        }
      }
    },
    splitButtonMenuButtonDisabled: {
      backgroundColor: s.buttonBackgroundDisabled,
      selectors: {
        ':hover': {
          backgroundColor: s.buttonBackgroundDisabled
        }
      }
    },
    splitButtonDivider: _objectSpread2(_objectSpread2({}, splitButtonDividerBaseStyles()), {}, {
      backgroundColor: p.neutralTertiaryAlt,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'WindowText'
      })
    }),
    splitButtonDividerDisabled: {
      backgroundColor: theme.palette.neutralTertiaryAlt
    },
    splitButtonMenuButtonChecked: {
      backgroundColor: p.neutralQuaternaryAlt,
      selectors: {
        ':hover': {
          backgroundColor: p.neutralQuaternaryAlt
        }
      }
    },
    splitButtonMenuButtonExpanded: {
      backgroundColor: p.neutralQuaternaryAlt,
      selectors: {
        ':hover': {
          backgroundColor: p.neutralQuaternaryAlt
        }
      }
    },
    splitButtonMenuIcon: {
      color: s.buttonText
    },
    splitButtonMenuIconDisabled: {
      color: s.buttonTextDisabled
    }
  };
}
function primaryStyles(theme) {
  var _selectors6, _selectors13;

  var p = theme.palette,
      s = theme.semanticColors;
  return {
    root: {
      backgroundColor: s.primaryButtonBackground,
      color: s.primaryButtonText,
      border: "1px solid ".concat(s.primaryButtonBackground),
      selectors: (_selectors6 = {}, _defineProperty(_selectors6, HighContrastSelector, {
        color: 'Window',
        backgroundColor: 'WindowText',
        MsHighContrastAdjust: 'none'
      }), _defineProperty(_selectors6, ".".concat(IsFocusVisibleClassName, " &:focus"), {
        selectors: {
          ':after': {
            border: "none",
            outlineColor: p.white
          }
        }
      }), _selectors6)
    },
    rootHovered: {
      backgroundColor: s.primaryButtonBackgroundHovered,
      color: s.primaryButtonTextHovered,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Window',
        backgroundColor: 'Highlight'
      })
    },
    rootPressed: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      color: s.primaryButtonTextPressed,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Window',
        backgroundColor: 'WindowText',
        MsHighContrastAdjust: 'none'
      })
    },
    rootExpanded: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      color: s.primaryButtonTextPressed
    },
    rootChecked: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      color: s.primaryButtonTextPressed
    },
    rootCheckedHovered: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      color: s.primaryButtonTextPressed
    },
    rootDisabled: {
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText',
        borderColor: 'GrayText',
        backgroundColor: 'Window'
      })
    },
    // Split button styles
    splitButtonContainer: {
      selectors: _defineProperty({}, HighContrastSelector, {
        border: 'none'
      })
    },
    splitButtonDivider: _objectSpread2(_objectSpread2({}, splitButtonDividerBaseStyles()), {}, {
      backgroundColor: p.white,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Window'
      })
    }),
    splitButtonMenuButton: {
      backgroundColor: s.primaryButtonBackground,
      color: s.primaryButtonText,
      selectors: (_selectors13 = {}, _defineProperty(_selectors13, HighContrastSelector, {
        backgroundColor: 'WindowText'
      }), _defineProperty(_selectors13, ':hover', {
        backgroundColor: s.primaryButtonBackgroundHovered,
        selectors: _defineProperty({}, HighContrastSelector, {
          color: 'Highlight'
        })
      }), _selectors13)
    },
    splitButtonMenuButtonDisabled: {
      backgroundColor: s.primaryButtonBackgroundDisabled,
      selectors: {
        ':hover': {
          backgroundColor: s.primaryButtonBackgroundDisabled
        }
      }
    },
    splitButtonMenuButtonChecked: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      selectors: {
        ':hover': {
          backgroundColor: s.primaryButtonBackgroundPressed
        }
      }
    },
    splitButtonMenuButtonExpanded: {
      backgroundColor: s.primaryButtonBackgroundPressed,
      selectors: {
        ':hover': {
          backgroundColor: s.primaryButtonBackgroundPressed
        }
      }
    },
    splitButtonMenuIcon: {
      color: s.primaryButtonText
    },
    splitButtonMenuIconDisabled: {
      color: p.neutralTertiary,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText'
      })
    }
  };
}

export { primaryStyles, standardStyles };
