import { inherits as _inherits, createSuper as _createSuper, classCallCheck as _classCallCheck, createClass as _createClass, objectSpread2 as _objectSpread2 } from '../../../../../_virtual/_rollupPluginBabelHelpers.js';
import { __decorate, __metadata } from '../../../../../node_modules/tslib/tslib.es6.js';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent$1 from '../BaseComponent.js';
import { concatStyleSetsWithProps } from '@uifabric/merge-styles';
import { getStyles } from './CalloutContent.styles.js';
import { clickedOutside as clickedOutside$1 } from '../../utilities/clickedOutside.js';
import { DirectionalHint as DirectionalHint$1 } from '../../common/DirectionalHint.js';
import { positionCallout, getBoundsFromTargetWindow } from '../../utilities/positioning/positioning.js';

var getClassNames = classNamesFunction();

var CalloutContentBase = /*#__PURE__*/function (_BaseComponent) {
  _inherits(CalloutContentBase, _BaseComponent);

  var _super = _createSuper(CalloutContentBase);

  function CalloutContentBase() {
    var _this;

    _classCallCheck(this, CalloutContentBase);

    _this = _super.apply(this, arguments);
    _this.internalKey = new Date();
    _this.positions = null;
    _this.positionAttempts = 0;
    return _this;
  }

  _createClass(CalloutContentBase, [{
    key: "created",
    value: function created() {
      window.addEventListener('click', this.onGlobalClick, true);
      window.addEventListener('scroll', this.onGlobalScroll, true);
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      window.removeEventListener('click', this.onGlobalClick, true);
      window.removeEventListener('scroll', this.onGlobalScroll, true);
    }
  }, {
    key: "updated",
    value: function updated() {
      this.internalKey = new Date();
    }
  }, {
    key: "mounted",
    value: function mounted() {
      this.updatePosition();
    }
  }, {
    key: "updatePosition",
    value: function updatePosition() {
      var positions = this.positions;

      var currentProps = _objectSpread2({}, this.$props);

      currentProps.bounds = this._getBounds();
      currentProps.target = this.target;
      var newPositions = positionCallout(currentProps, this.$refs.hostElement, this.$refs.calloutElement, this.positions);

      if (!positions && newPositions || positions && newPositions && !this._arePositionsEqual(positions, newPositions) && this.positionAttempts < 5) {
        this.positionAttempts++;
        this.positions = newPositions;
      } else if (this.positionAttempts > 0) {
        this.positionAttempts = 0;
        this.$emit('positioned', this.positions);
      }
    }
  }, {
    key: "_getBounds",
    value: function _getBounds() {
      if (!this._bounds) {
        var bounds = this.bounds;
        var currentBounds = typeof bounds === 'function' ? bounds(this.target, window) : bounds;

        if (!currentBounds) {
          currentBounds = getBoundsFromTargetWindow(this.target, window);
          currentBounds = {
            top: currentBounds.top + this.minPagePadding,
            left: currentBounds.left + this.minPagePadding,
            right: currentBounds.right - this.minPagePadding,
            bottom: currentBounds.bottom - this.minPagePadding,
            width: currentBounds.width - this.minPagePadding * 2,
            height: currentBounds.height - this.minPagePadding * 2
          };
        }

        this._bounds = currentBounds;
      }

      return this._bounds;
    }
  }, {
    key: "onGlobalClick",
    value: function onGlobalClick(e) {
      var outside = clickedOutside$1(e, this.$refs.calloutElement);
      if (outside) this.$emit('dismiss', e, 'click');
    }
  }, {
    key: "onGlobalScroll",
    value: function onGlobalScroll(e) {
      var outside = clickedOutside$1(e, this.$refs.calloutElement);
      if (outside) this.$emit('dismiss', e, 'scroll');
    }
  }, {
    key: "_arePositionsEqual",
    value: function _arePositionsEqual(positions, newPosition) {
      return this._comparePositions(positions.elementPosition, newPosition.elementPosition) && this._comparePositions(positions.beakPosition.elementPosition, newPosition.beakPosition.elementPosition);
    }
  }, {
    key: "_comparePositions",
    value: function _comparePositions(oldPositions, newPositions) {
      for (var key in newPositions) {
        // This needs to be checked here and below because there is a linting error if for in does not immediately have an if statement
        if (newPositions.hasOwnProperty(key)) {
          var oldPositionEdge = oldPositions[key];
          var newPositionEdge = newPositions[key];

          if (oldPositionEdge !== undefined && newPositionEdge !== undefined) {
            if (oldPositionEdge.toFixed(2) !== newPositionEdge.toFixed(2)) {
              return false;
            }
          } else {
            return false;
          }
        }
      }

      return true;
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          positionCss = this.positionCss,
          isBeakVisible = this.isBeakVisible;
      return h("div", {
        "ref": "hostElement",
        "class": classNames.container
      }, [h("div", {
        "ref": "calloutElement",
        "class": classNames.root,
        "style": positionCss ? positionCss.elementPosition : null
      }, [isBeakVisible && h("div", {
        "class": classNames.beak,
        "style": positionCss && positionCss.beakPosition ? positionCss.beakPosition.elementPosition : null
      }), isBeakVisible && h("div", {
        "class": classNames.beakCurtain
      }), h("div", {
        "class": classNames.calloutMain
      }, [this.$slots.default])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          positions = this.positions,
          styles = this.styles,
          calloutWidth = this.calloutWidth,
          beakWidth = this.beakWidth;
      return getClassNames(concatStyleSetsWithProps({
        theme: theme,
        className: className,
        overflowYHidden: false,
        calloutWidth: calloutWidth,
        beakWidth: beakWidth,
        backgroundColor: '#fff',
        calloutMaxWidth: '100%'
      }, getStyles, styles));
    }
  }, {
    key: "actualBeakWidth",
    get: function get() {
      return Math.sqrt(this.beakWidth * this.beakWidth * 2);
    }
  }, {
    key: "positionCss",
    get: function get() {
      if (!this.positions) return null;
      var positionCss = this.positions;

      for (var key in positionCss.elementPosition) {
        positionCss.elementPosition[key] = "".concat(positionCss.elementPosition[key], "px");
      }

      for (var _key in positionCss.beakPosition.elementPosition) {
        positionCss.beakPosition.elementPosition[_key] = "".concat(positionCss.beakPosition.elementPosition[_key], "px");
      }

      return positionCss;
    }
  }]);

  return CalloutContentBase;
}(BaseComponent$1);

__decorate([Prop({
  type: HTMLElement,
  required: true
}), __metadata("design:type", HTMLElement)], CalloutContentBase.prototype, "target", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], CalloutContentBase.prototype, "calloutWidth", void 0);

__decorate([Prop({
  type: Number,
  default: 16
}), __metadata("design:type", Number)], CalloutContentBase.prototype, "beakWidth", void 0);

__decorate([Prop({
  type: Number,
  default: 8
}), __metadata("design:type", Number)], CalloutContentBase.prototype, "minPagePadding", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], CalloutContentBase.prototype, "isBeakVisible", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CalloutContentBase.prototype, "coverTarget", void 0);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], CalloutContentBase.prototype, "gapSpace", void 0);

__decorate([Prop({
  type: Number,
  default: DirectionalHint$1.bottomAutoEdge
}), __metadata("design:type", Boolean)], CalloutContentBase.prototype, "directionalHint", void 0);

__decorate([Prop({
  type: [Object, Function],
  default: null
}), __metadata("design:type", Object)], CalloutContentBase.prototype, "bounds", void 0);

CalloutContentBase = __decorate([Component], CalloutContentBase);

export { CalloutContentBase };
