import { defineProperty as _defineProperty, objectSpread2 as _objectSpread2 } from '../../../../../_virtual/_rollupPluginBabelHelpers.js';
import { getGlobalClassNames } from '@uifabric/styling';
import { parseGap, parsePadding } from './StackUtils.js';

var nameMap = {
  start: 'flex-start',
  end: 'flex-end'
};
var GlobalClassNames = {
  root: 'ms-Stack',
  inner: 'ms-Stack-inner'
};
var styles = function styles(props, theme, tokens) {
  var verticalFill = props.verticalFill,
      horizontal = props.horizontal,
      reversed = props.reversed,
      gap = props.gap,
      grow = props.grow,
      wrap = props.wrap,
      horizontalAlign = props.horizontalAlign,
      verticalAlign = props.verticalAlign,
      disableShrink = props.disableShrink,
      className = props.className;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var childrenGap = tokens && tokens.childrenGap ? tokens.childrenGap : gap;
  var maxHeight = tokens && tokens.maxHeight ? tokens.maxHeight : props.maxHeight;
  var maxWidth = tokens && tokens.maxWidth ? tokens.maxWidth : props.maxWidth;
  var padding = tokens && tokens.padding ? tokens.padding : props.padding;

  var _parseGap = parseGap(childrenGap, theme),
      rowGap = _parseGap.rowGap,
      columnGap = _parseGap.columnGap;

  var horizontalMargin = "".concat(-0.5 * columnGap.value).concat(columnGap.unit);
  var verticalMargin = "".concat(-0.5 * rowGap.value).concat(rowGap.unit); // styles to be applied to all direct children regardless of wrap or direction

  var childStyles = {
    textOverflow: 'ellipsis'
  }; // selectors to be applied regardless of wrap or direction

  var commonSelectors = {
    // flexShrink styles are applied by the StackItem
    '> *:not(.ms-StackItem)': {
      flexShrink: disableShrink ? 0 : 1
    }
  };

  if (wrap) {
    return {
      root: [classNames.root, {
        flexWrap: 'wrap',
        maxWidth: maxWidth,
        maxHeight: maxHeight,
        width: 'auto',
        overflow: 'visible',
        height: '100%'
      }, horizontalAlign && _defineProperty({}, horizontal ? 'justifyContent' : 'alignItems', nameMap[horizontalAlign] || horizontalAlign), verticalAlign && _defineProperty({}, horizontal ? 'alignItems' : 'justifyContent', nameMap[verticalAlign] || verticalAlign), className, {
        // not allowed to be overridden by className
        // since this is necessary in order to prevent collapsing margins
        display: 'flex'
      }, horizontal && {
        height: verticalFill ? '100%' : 'auto'
      }],
      inner: [classNames.inner, {
        display: 'flex',
        flexWrap: 'wrap',
        marginLeft: horizontalMargin,
        marginRight: horizontalMargin,
        marginTop: verticalMargin,
        marginBottom: verticalMargin,
        overflow: 'visible',
        boxSizing: 'border-box',
        padding: parsePadding(padding, theme),
        // avoid unnecessary calc() calls if horizontal gap is 0
        width: columnGap.value === 0 ? '100%' : "calc(100% + ".concat(columnGap.value).concat(columnGap.unit, ")"),
        maxWidth: '100vw',
        selectors: _objectSpread2({
          '> *': _objectSpread2({
            margin: "".concat(0.5 * rowGap.value).concat(rowGap.unit, " ").concat(0.5 * columnGap.value).concat(columnGap.unit)
          }, childStyles)
        }, commonSelectors)
      }, horizontalAlign && _defineProperty({}, horizontal ? 'justifyContent' : 'alignItems', nameMap[horizontalAlign] || horizontalAlign), verticalAlign && _defineProperty({}, horizontal ? 'alignItems' : 'justifyContent', nameMap[verticalAlign] || verticalAlign), horizontal && {
        flexDirection: reversed ? 'row-reverse' : 'row',
        // avoid unnecessary calc() calls if vertical gap is 0
        height: rowGap.value === 0 ? '100%' : "calc(100% + ".concat(rowGap.value).concat(rowGap.unit, ")"),
        selectors: {
          '> *': {
            maxWidth: columnGap.value === 0 ? '100%' : "calc(100% - ".concat(columnGap.value).concat(columnGap.unit, ")")
          }
        }
      }, !horizontal && {
        flexDirection: reversed ? 'column-reverse' : 'column',
        height: "calc(100% + ".concat(rowGap.value).concat(rowGap.unit, ")"),
        selectors: {
          '> *': {
            maxHeight: rowGap.value === 0 ? '100%' : "calc(100% - ".concat(rowGap.value).concat(rowGap.unit, ")")
          }
        }
      }]
    };
  }

  return {
    root: [classNames.root, {
      display: 'flex',
      flexDirection: horizontal ? reversed ? 'row-reverse' : 'row' : reversed ? 'column-reverse' : 'column',
      flexWrap: 'nowrap',
      width: 'auto',
      height: verticalFill ? '100%' : 'auto',
      maxWidth: maxWidth,
      maxHeight: maxHeight,
      padding: parsePadding(padding, theme),
      boxSizing: 'border-box',
      selectors: _objectSpread2(_defineProperty({
        '> *': childStyles
      }, reversed ? '> *:not(:last-child)' : '> *:not(:first-child)', [horizontal && {
        marginLeft: "".concat(columnGap.value).concat(columnGap.unit)
      }, !horizontal && {
        marginTop: "".concat(rowGap.value).concat(rowGap.unit)
      }]), commonSelectors)
    }, grow && {
      flexGrow: grow === true ? 1 : grow
    }, horizontalAlign && _defineProperty({}, horizontal ? 'justifyContent' : 'alignItems', nameMap[horizontalAlign] || horizontalAlign), verticalAlign && _defineProperty({}, horizontal ? 'alignItems' : 'justifyContent', nameMap[verticalAlign] || verticalAlign), className]
  };
};

export { styles };
