import { createTheme, loadTheme as loadTheme$1 } from '@uifabric/styling';
import { toKebabCase as toKebabCase$1 } from '../utilities/toKebabCase.js';
import * as Components from '../components/index.js';
import { registerCSSVars as registerCSSVars$1 } from './registerCSSVars.js';

function loadTheme(theme) {
  var useCSSVars = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  var _theme = createTheme(theme);

  if (useCSSVars) {
    var palette = _theme.palette,
        semanticColors = _theme.semanticColors; // generate new css vars

    palette = registerCSSVars$1('palette', palette);
    semanticColors = registerCSSVars$1('semanticColors', semanticColors); // update theme

    loadTheme$1({
      palette: palette,
      semanticColors: semanticColors
    });
  }

  return _theme;
}
function install(Vue) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var theme = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  for (var componentName in Components) {
    var Component = Components[componentName];

    if (Component && Component.prototype instanceof Vue) {
      var name = "".concat(options.prefix || 'f', "-").concat(toKebabCase$1(componentName));
      Vue.component(name, Component);
    }
  }

  loadTheme(theme, options.useCSSVars);
}
/*

============================
    CSS Vars
--neutralLight: #eaeaea;
--bodyFrameBackground: var(--neutralLight)

{
  neutralLight: 'var(--neutralLight)'
}
{
  bodyFrameBackground: 'var(--neutralLight)'
}

======================================
    No CSS Vars
{
  neutralLight: '#eaeaea'
}
{
  bodyFrameBackground: '#eaeaea'
}

 */

export default install;
export { loadTheme };
